@@ -158,7 +158,7 @@ class Elements():
                 # will not get <Image>, <StrokeThickness>, <ImageLocation>, or sencil constraints
                         # get all property data (all child elements)
 
-                my_list = [self.ele_name,ele_type,self.ele_id,self.ele_desc,self.ele_parent,self.hidden,self.rep, self.attribs]
+                my_list = [self.ele_name,ele_type,self.ele_id,self.ele_desc,self.ele_parent,self.hidden,self.rep]
                 for col_num, data in enumerate(my_list):
                     stencil_worksheet.write(self.row, col_num, data)
 
@@ -269,7 +269,6 @@ def main():
     stencil_worksheet.write('E1', 'Parent', bold)
     stencil_worksheet.write('F1', 'Hidden_bool', bold)
     stencil_worksheet.write('G1', 'Representation', bold)
-    stencil_worksheet.write('H1', 'Attributes', bold)
 
     # write generic elements
     Ele = Elements()
